@@ -44,34 +44,44 @@ print.mscmt <- function(x,...) {
         nosunny = paste0("Perfect predictor fit possible, ie. predictor ",
           "weights V are meaningless since only W's with perfect preditor ",
           "fit are considered for optimization of the 'dependent' loss."),
+        onesunny = paste0("Predictor weights V are meaningless since one ",
+          "single donor always achieves best predictor fit (irrespective of ",
+          "particular choice of predictor weights)."),
         fixed = paste0("Vector V was fixed, outer optimization bypassed."),
         regression = paste0("Vector V was determined by regression, ",
           "outer optimization bypassed."),
         artificial = paste0("Artificial solution, vector W was fixed."),
+        global = paste0("Unrestricted outer optimum obtained by ignoring all ",
+          "predictors is feasible even when respecting the predictors."),
         paste0("Ordinary solution, ie. no perfect preditor fit possible and ",
-          "the predictors always impose some restrictions on the optimization ",
-          "of the 'dependent' loss.")),mwd,ind),
+          "the predictors impose some restrictions on the outer optimization.")
+        ),mwd,ind),
       csl("Optimal W",align(names(ess(x1$w)),": ",
                             format(100*ess(x1$w),scientific=FALSE),"%"),
           mwd,ind),
       csl("Dependent loss",align(c("MSPE ('loss V')","RMSPE"),": ",
                                  c(x1$loss.v,x1$rmspe)),mwd,ind,TRUE),
+#      if((x1$solution.type!="global")&&((!is.na(x1$outer.rmspe))))
+#        csl("Infeas. opt.",align(c("MSPE ('loss V')","RMSPE"),": ",
+#            c(x1$outer.rmspe^2,x1$outer.rmspe)),mwd,ind,TRUE),
       if(length(x1$dependent)>1) paste0(
         csl("Unscaled MSPE",x1$mspe.unscaled,mwd,ind),                               
         csl("Individ. MSPEs",align(x1$dependent,": ",x1$mspes),mwd,ind)                               
       ),  
       wrap("(Optimal) V",switch(x1$solution.type,
         nosunny = paste0("Predictor weights V are meaningless."),
+        onesunny = paste0("Predictor weights V are meaningless."),
         fixed = paste0("Fixed predictor weights V (not necessarily optimal)."),
         regression = paste0("Regression-based predictor weights V (not ",
                             "necessarily optimal)."),
-        artificial = paste0("Artificial solution, vector V was either fixed ",
-                            "or artificially constructed based on fixed W."),
+        artificial = paste0("Artificial solution, predictor weights V were ",
+                            "either fixed or artificially constructed ",
+                            "based on fixed donor weights."),
         paste0(if (isTRUE(x1$single.v)) "Single predictor weights V requested. ",
           if (!isTRUE(x1$single.v)) "Some optimal " else "The optimal ",
           "weight vector",
           if (!isTRUE(x1$single.v)) "s V are:" else " V is:")),mwd,ind),
-      if (x1$solution.type!="nosunny") paste0(
+      if ((x1$solution.type!="nosunny")&&(x1$solution.type!="onesunny")) paste0(
         paste0(paste0(paste0(rep(" ",ind),collapse=""),Vmat),collapse="\n"),
         "\n",
         wrap("",paste0("(Predictor weights V are standardized by ",x1$std.v,
